YARP 2.3.66 (2016-06-01)                                              {#v2_3_66}
========================

[TOC]

YARP 2.3.66 Release Notes
=========================


A (partial) list of bug fixed and issues resolved in this release can be found
[here](https://github.com/robotology/yarp/issues?q=label%3A%22Fixed+in%3A+vYARP+2.3.66%22).


Important Changes
-----------------

### YARP_dev

* The `yarp::dev::IDepthSensor`, `yarp::dev::IRGBDSensor` interfaces and the
  `RGBDSensorClient` and `RGBDSensorWrapper` devices, that were erroneously
  introduced were removed.

Bug Fixes
---------

### CMake Modules

* `StandardFindModule`: Fix `INTERFACE_COMPILE_DEFINITIONS` and
  `INTERFACE_COMPILE_OPTIONS` properties.

### YARP_dev

* Add missing `YARP_dev_API` export symbol to `StubImplPositionDirectRaw`
* Fixed errors on ROS topic message, in particular:
  * measurement unit for linear joints.
  * timeStamps for joint message. This fixes issue on ROS TF while using
    simulator.
* `RemoteFrameGrabber`: moved template explicit instantiation into .cpp to avoid
  duplicating symbols.

### Modules

* Critical bugfix for laserHokuyo

### GUIs

* `yarpmanager++`: fixed crashes on deleting connection after changing prefix (#761)
* `yarpmanager++`: fixed connections do not update when prefix is changed (#751)
* `yarpmanager++`: fixed icon on Mac OSX (#758)


Contributors
------------

This is a list of people that contributed to this release (generated from the
git history using `git shortlog -ens --no-merges v2.3.65..v2.3.66`):

```
    18	Daniele E. Domenichelli <daniele.domenichelli@iit.it>
     3	Alberto Cardellino <alberto.cardellino@iit.it>
     3	Matteo Brunettini <matteo.brunettini@iit.it>
     3	Silvio Traversaro <silvio.traversaro@iit.it>
     1	Claudio Fantacci <claudio.fantacci@iit.it>
     1	Davide Perrone <dperrone@aitek.it>
     1	Lorenzo Natale <lorenzo.natale@iit.it>
     1	Marco Randazzo <marco.randazzo@iit.it>
     1	Ugo Pattacini <ugo.pattacini@iit.it>
```
